MethodChannelScreenHelper class

An implementation of ScreenHelperPlatform that uses method channels.

Inheritance

Constructors

MethodChannelScreenHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getScreenDiagonalInInches() → Future<double?>
Fetches the screen's diagonal size in inches.
override
getScreenDiagonalInPixels() → Future<int?>
Fetches the screen's diagonal size in pixels.
override
getScreenHeightInInches() → Future<double?>
Fetches the screen's height size in inches.
override
getScreenPPI() → Future<double?>
Fetches the screen's PPI (Pixels Per Inch).
override
getScreenRealHeightInPixels() → Future<int?>
Fetches the screen's real height in pixels.
override
getScreenRealWidthInPixels() → Future<int?>
Fetches the screen's real width in pixels.
override
getScreenWidthInInches() → Future<double?>
Fetches the screen's width size in inches.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited