ScreenHelperPlatform class abstract

The interface that implementations of screen_helper must implement.

Inheritance
  • Object
  • PlatformInterface
  • ScreenHelperPlatform
Implementers

Constructors

ScreenHelperPlatform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getScreenDiagonalInInches() → Future<double?>
getScreenDiagonalInPixels() → Future<int?>
Returns the screen diagonal size in pixels.
getScreenHeightInInches() → Future<double?>
getScreenPPI() → Future<double?>
getScreenRealHeightInPixels() → Future<int?>
Returns the real screen height in pixels.
getScreenRealWidthInPixels() → Future<int?>
Returns the real screen width in pixels.
getScreenWidthInInches() → Future<double?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ ScreenHelperPlatform
getter/setter pair